@@ -4,12 +4,18 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
   mi <- insight::model_info(model)
 
+  is_multivariate <- isTRUE(model@extra$multiple.responses)
+
   # compute ci, two-ways
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
     ci <- 0.975
 
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+
   if ((mi$is_ordinal || mi$is_multinomial) && !isTRUE(se)) {
     type <- "response"
   } else {
@@ -24,9 +30,9 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
     ...
   )
 
-  if (mi$is_ordinal || mi$is_multinomial) {
+  if (mi$is_ordinal || mi$is_multinomial || is_multivariate) {
     # start here with cumulative link models
-    resp <- insight::get_response(model)
+    resp <- insight::get_response(model, verbose = FALSE)
 
     if (is.data.frame(resp))
       resp.names <- colnames(resp)
@@ -35,7 +41,9 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
 
     if (se) {
       dat <- data.frame(predicted = prdat$fitted.values)
-      resp.names <- resp.names[-1]
+      if (!is_multivariate) {
+        resp.names <- resp.names[-1]
+      }
     } else {
       dat <- data.frame(predicted = prdat)
       linv <- function(mu) mu
@@ -52,8 +60,8 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
     if (is.matrix(fitfram$predicted)) fitfram$predicted <- as.vector(fitfram$predicted[, 2])
 
     if (se) {
-      d1 <- data.frame(ci.low = prdat$fitted.values - stats::qnorm(ci) * prdat$se.fit)
-      d2 <- data.frame(ci.high = prdat$fitted.values + stats::qnorm(ci) * prdat$se.fit)
+      d1 <- data.frame(ci.low = prdat$fitted.values - tcrit * prdat$se.fit)
+      d2 <- data.frame(ci.high = prdat$fitted.values + tcrit * prdat$se.fit)
       d3 <- data.frame(se = prdat$se.fit)
       colnames(d1) <- sprintf("ci_low_%s", resp.names)
       colnames(d2) <- sprintf("ci_high_%s", resp.names)
@@ -80,8 +88,8 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
     # did user request standard errors? if yes, compute CI
     if (se) {
       # calculate CI
-      fitfram$conf.low <- suppressWarnings(linv(prdat$fitted.values - stats::qnorm(ci) * prdat$se.fit))
-      fitfram$conf.high <- suppressWarnings(linv(prdat$fitted.values + stats::qnorm(ci) * prdat$se.fit))
+      fitfram$conf.low <- suppressWarnings(linv(prdat$fitted.values - tcrit * prdat$se.fit))
+      fitfram$conf.high <- suppressWarnings(linv(prdat$fitted.values + tcrit * prdat$se.fit))
     } else {
       # no CI
       fitfram$conf.low <- NA
