@@ -14,6 +14,8 @@
                                     back.transform = FALSE,
                                     response.transform = NULL,
                                     vcov.args = NULL,
+                                    margin = NULL,
+                                    bias_correction = FALSE,
                                     verbose = TRUE) {
   # get axis titles and labels
   all.labels <- .get_axis_titles_and_labels(
@@ -53,6 +55,8 @@
     response.transform = response.transform,
     original_model_frame = original_model_frame,
     vcov.args = vcov.args,
+    margin = margin,
+    bias_correction = bias_correction,
     verbose = verbose
   )
 }
