@@ -6,7 +6,7 @@
   value_adjustment,
   terms,
   model_class = NULL,
-  type = "fe",
+  type = "fixed",
   vcov.fun = NULL,
   vcov.type = NULL,
   vcov.args = NULL,
@@ -60,12 +60,7 @@
                                condition,
                                interval) {
 
-  model_frame <- insight::get_data(model, source = "frame")
-
-  # sanity check - could data be extracted from model frame?
-  if (is.null(model_frame)) {
-    model_frame <- .safe(insight::get_data(model, source = "environment"))
-  }
+  model_frame <- .get_model_data(model)
 
   # check random effect terms. We can't compute SE if data has
   # factors with only one level, however, if user conditions on
@@ -145,7 +140,7 @@
   pr_int <- FALSE
 
   if (is.null(vmatrix)) {
-    insight::format_alert("Could not compute variance-covariance matrix of predictions. No confidence intervals are returned.")
+    insight::format_alert("Could not compute variance-covariance matrix of predictions. No confidence intervals are returned.") # nolint
     se.fit <- NULL
   } else {
     pvar <- vmatrix
@@ -166,9 +161,9 @@
     match_len <- isTRUE(n_pred %% n_se == 0)
 
     # shorten to length of prediction_data
-    if (!is.null(model_class) && model_class %in% c("polr", "multinom", "mixor")) {
+    if (!is.null(model_class) && model_class %in% c("polr", "multinom", "mixor", "multinom_weightit")) {
       se.fit <- rep(se.fit, each = .n_distinct(prediction_data$response.level))
-    } else if (type == "re" && n_se < n_pred && match_len) {
+    } else if (type == "random" && n_se < n_pred && match_len) {
       se.fit <- rep(se.fit, each = n_pred / n_se)
     } else {
       se.fit <- se.fit[1:n_pred]
